@@ -42,10 +42,7 @@ try:
 except ImportError:
     module_logger.exception("No sqlalchemy package found")
     raise MyError
-try:
-    import sqlalchemy.exceptions as sqlae
-except ImportError:
-    from sqlalchemy import exc as sqlae
+
 # attempt to prevent sqlalchemy trhowing recursion limit error
 sys.setrecursionlimit(2000) # 1000 is the default
 
@@ -512,6 +509,10 @@ class RowMapper:
     def commit(self):
         """Flush dbase data to disk.
         Returns None on success and True on faillure."""
+        if not self.orm:
+            self.logger.info("No orm, nothing to store")
+            return
+
         self.logger.debug("orm %s commit data to dbase" % self.orm._name)
         if hasattr(self.orm, 'user_id'):
             self.insert('user_id', self.user_id)
@@ -586,7 +587,7 @@ class ServedMapper:
 class BogusMapper:
     """Bogus mapper class used when we are in anonymousmode"""
     def __init__(self):
-        pass
+        self._name = 'Bogusmapper'
     def __str__(self):
         return "BogusMapper"
     def __repr__(self):
@@ -609,8 +610,6 @@ class BogusMapper:
         pass
     def get_table_selection(self, args):
         pass
-    def _get_level_data(self, levelnum=1):
-        pass
     def _get_start_time(self):
         return "2000-01-01_00:00:00"
     def _get_end_time(self):
